<?php
/**
 * $Id: details.php 280 2007-06-05 02:57:36Z hodaka $
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

require_once dirname(dirname(__FILE__)).'/include/header.php';
require_once dirname(dirname(__FILE__)).'/class/class.weblog.php';
require_once dirname(dirname(__FILE__)).'/class/class.weblogcategories.php';
require_once dirname(dirname(__FILE__)).'/class/class.weblogtrackback.php';

// obtain GET/POST parameters
$blog_id = !empty($_GET['blog_id']) ? intval($_GET['blog_id']) : 0;
$cat_id = !empty($_GET['cat_id']) ? intval($_GET['cat_id']) : 0;
$date = !empty($_GET['date']) ? intval($_GET['date']) : 0; // YYYY or YYYYMM or YYYYMMDD
$user_id = !empty($_GET['user_id']) ? intval($_GET['user_id']) : 0;

// Determine the user we are retrieving for the blog entries
if (is_object($xoopsUser)) {
    $isAdmin = $xoopsUser->isAdmin($xoopsModule->mid());
    $currentuid = $xoopsUser->getVar('uid');
    $useroffset = $xoopsUser->timezone() - $xoopsConfig['server_TZ'] ;   
} else {
    $isAdmin = false;
    $currentuid = 0;
    $useroffset = $xoopsConfig['default_TZ'] - $xoopsConfig['server_TZ'] ; 
}

// privilege check
require_once dirname(dirname(__FILE__)).'/include/privilege.inc.php';
if( ! $isAdmin && ! checkprivilege( 'read_detail' , $xoopsModule->dirname() ) ){
    redirect_header(sprintf('%s/index.php', XOOPS_URL ), 2, _MD_WEBLOG_CANNOT_READ_SORRY);
    exit();
}

// specify template
$xoopsOption['template_main'] = $mydirname.'_main_details.html';

// obtain class instances
$myts =& MyTextSanitizer::getInstance();
$weblog =& Weblog::getInstance();
$weblogcat =& WeblogCategories::getInstance();

// fetch his/her blog details
$entryObject =& $weblog->getEntry($currentuid, $blog_id, 0, $useroffset);
if (!$entryObject) {
	redirect_header(sprintf('%s/modules/%s/index.php', XOOPS_URL, $xoopsModule->dirname()), 1, _MD_WEBLOG_PRIVATE_NOTEXIST_SORRY);
	exit();
}

// obtain trackback
$tb_operator =& Weblog_Trackback_Operator::getInstance() ;
$trackback_array = $tb_operator->handler->get( $entryObject->getVar('blog_id') ) ;
$trackback_transmit = array() ;
$trackback_received = array() ;
if( $trackback_array ){
	foreach( $trackback_array as $trackback_obj ){
		$trackback_data = array(
		'tb_url'=> $trackback_obj->getVar('tb_url'),
		'blog_name'=> $trackback_obj->getVar('blog_name'),
		'title'=> $trackback_obj->getVar('title'),
		'description'=> xoops_substr( $trackback_obj->getVar('description') , 0 , 120 ),
		'link'=> $trackback_obj->getVar('link'),
		'trackback_created'=> formatTimestamp($trackback_obj->getVar('trackback_created'), 'Y-m-d/H:i:s' , $xoopsConfig['default_TZ']));
		if( $trackback_obj->getVar('direction') == 'transmit' ){
			$trackback_transmit[] = $trackback_data ;
		}elseif( $trackback_obj->getVar('direction') == 'received' ){
			$trackback_received[] = $trackback_data ;
		}
	}
}
// (ex. IIS)
if( (isset( $_SERVER['SERVER_SOFTWARE'] ) && preg_match("/Microsoft-IIS/i",$_SERVER['SERVER_SOFTWARE'])) || ! isset( $_SERVER['REQUEST_URI'] ) ){
	$delimiter = "?" ;
}else{
	$delimiter = "/" ;
}
$weblog_trackback_url = XOOPS_URL.'/modules/'.$xoopsModule->dirname().'/weblog-tb.php' . $delimiter . $blog_id  ;

// wellwine for cookie begins
// Read in cookie
$weblog_read = !empty($_COOKIE[WEBLOG_COOKIE_READ]) ? unserialize($_COOKIE[WEBLOG_COOKIE_READ]) : array();
// if cookie is not set for this blog, update view count and set cookie (and auther or Admin does not count)
$curtime = time();
if ( empty($weblog_read[$blog_id]) || $weblog_read[$blog_id] + $xoopsModuleConfig['expiration'] < $curtime ) {
    if( !(is_object($xoopsUser) && ($isAdmin || $xoopsUser->getVar('uid')==$entryObject->getVar('user_id'))) ) {
        $reads = $weblog->incrementReads($blog_id);
        $entryObject->setVar('reads', $reads);
    }
}
// Update cookie
// FIXME: doesn't check if 4kB limit of cookie is exceeded!
$weblog_read[$blog_id] = $curtime;
setcookie(WEBLOG_COOKIE_READ, serialize($weblog_read), $curtime+$xoopsModuleConfig['expiration'], $weblogCookie['path'], $weblogCookie['domain'], $weblogCookie['secure']);
// wellwine for cookie ends

// Setup the user_id in the HTTP_GET so that the Notifications module will pick it up
$_GET['user_id'] = $entryObject->getVar('user_id');

// Retrieve his/her avatar
$use_avatar = 0;
$avatar_img = '';
$avatar_width = 0;
$avatar_height = 0;
if ($xoopsModuleConfig['showavatar']) {
    $avatar = $entryObject->getVar('user_avatar', 'E');
    if (!empty($avatar) && $avatar != 'blank.gif') {
        $use_avatar = 1;
        $avatar_img = sprintf('%s/uploads/%s', XOOPS_URL, $avatar);
        $dimension = ( ini_get('allow_url_fopen') ) ? getimagesize(sprintf('%s/%s', XOOPS_UPLOAD_PATH, $avatar)) : '' ;
        $avatar_width = ( is_array($dimension) ) ? $dimension[0] : '' ;
        $avatar_height = ( is_array($dimension) ) ? $dimension[1] : '' ;
    }
}

$entry_contents = $entryObject->getVar('contents','s' , $entryObject->getVar('blog_id') ,'details' );

// create rdf 
require_once dirname(dirname(__FILE__)).'/include/PEAR/Net/TrackBack.php';
$net_trackback =& new Net_TrackBack() ;
if( $xoopsConfig['default_TZ'] < 0 ){
	$TZ = "-" . sprintf('%02d' , abs($xoopsConfig['default_TZ']) ) . ':00';
}else{
	$TZ = "+" . sprintf('%02d' , $xoopsConfig['default_TZ'] ) . ':00';
}
$rdf_source_data = array(
 	'about'=> sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL , $xoopsModule->dirname() , $entryObject->getVar('blog_id') ) ,
	'ping'=> $weblog_trackback_url ,
	'title'=> addslashes($entryObject->getVar('title')) ,
	'identifier'=> sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL , $xoopsModule->dirname() , $entryObject->getVar('blog_id') ) ,
	'description'=> strip_tags(addslashes(xoops_substr( $entry_contents , 0 , WEBLOG_RDF_DESCRIPTION_NUM ))) ,
	'creator'=> $entryObject->getVar('uname'),
	'date'=> date("Y-m-d\TH:i:s" , $entryObject->getVar('created')) . $TZ
) ;
$rdf_desc = '<!-- \n' . $net_trackback->toEmbededRDF($rdf_source_data) . "-->\n";

// Include the page header
include(XOOPS_ROOT_PATH.'/header.php');

$xoopsTpl->assign('use_avatar',$use_avatar);
$xoopsTpl->assign('avatar_img',$avatar_img);
$xoopsTpl->assign('avatar_width', $avatar_width);
$xoopsTpl->assign('avatar_height', $avatar_height);

$xoopsTpl->assign('title', $entryObject->getVar('title'));
$catpath = $weblogcat->getNicePathArrayFromId($entryObject->getVar('cat_id'),
                            sprintf('%s/modules/%s/index.php', XOOPS_URL, $mydirname));
$xoopsTpl->assign('category', $catpath);
$xoopsTpl->assign('blog_id', $entryObject->getVar('blog_id'));
$xoopsTpl->assign('created', formatTimestamp($entryObject->getVar('created'),
                              	$xoopsModuleConfig['dateformat'].' '.$xoopsModuleConfig['timeformat'],
                                                  $xoopsConfig['default_TZ']));
$xoopsTpl->assign('uid', $entryObject->getVar('user_id'));
$xoopsTpl->assign('uname', $entryObject->getVar('uname'));
$xoopsTpl->assign('contents', $entry_contents);
$xoopsTpl->assign('private', $entryObject->getVar('private'));
$xoopsTpl->assign('profileUri', sprintf('%s/userinfo.php?uid=%d', XOOPS_URL, $entryObject->getVar('user_id')));
$xoopsTpl->assign('current_uid', $currentuid);
$xoopsTpl->assign('is_private', $entryObject->getVar('private') == 'Y' ? 1 : 0);
$xoopsTpl->assign('comments_num', $entryObject->getVar('comments'));
$xoopsTpl->assign('reads', $entryObject->getVar('reads'));
$xoopsTpl->assign('trackbacks', $entryObject->getVar('trackbacks'));
//$xoopsTpl->assign('read_users_blog',sprintf('<a href="index.php?user_id=%d">%s</a>',
//                                            $entryObject->getVar('user_id'),
//                                            sprintf(_MD_WEBLOG_READ_USERS_BLOG, $entryObject->getVar('uname'))));
$xoopsTpl->assign('provide_edit_link', ($isAdmin || ($currentuid==$entryObject->getVar('user_id') && checkprivilege('edit',$mydirname)))?1:0);
$xoopsTpl->assign('blog_id', $blog_id);
$xoopsTpl->assign('print_link', 'print.php?blog_id='.$blog_id);
$xoopsTpl->assign('mail_link', 'mailto:?subject='.sprintf(_MD_WEBLOG_INTARTICLE,$xoopsConfig['sitename']).'&amp;body='.sprintf(_MD_WEBLOG_INTARTFOUND, $xoopsConfig['sitename']).':%20'.XOOPS_URL.'/modules/'.$xoopsModule->dirname().'/details.php?blog_id='.$blog_id);

$rss_feeder = sprintf('%s/modules/%s/backend_weblog.php', XOOPS_URL, $mydirname);
$rss_feeder .= sprintf('?user_id=%d', $entryObject->getVar('user_id'));
$rdf_feeder = sprintf('%s/modules/%s/weblog-rdf.php', XOOPS_URL, $mydirname);
$rdf_feeder .= sprintf('?user_id=%d', $entryObject->getVar('user_id'));
$atom_feeder = sprintf('%s/modules/%s/weblog-atom.php', XOOPS_URL, $mydirname);
$atom_feeder .= sprintf('?user_id=%d', $entryObject->getVar('user_id'));
$xoopsTpl->assign('lang_rss', sprintf(_MD_WEBLOG_RSS_RECENT_FOR, $entryObject->getVar('uname')));
$xoopsTpl->assign('rss_feeder', $rss_feeder);
$xoopsTpl->assign('rdf_feeder', $rdf_feeder);
$xoopsTpl->assign('atom_feeder', $atom_feeder);
$xoopsTpl->assign('rss_show', $xoopsModuleConfig['rssshow']);
$xoopsTpl->assign('rdf_desc', $rdf_desc);

$xoopsTpl->assign('page_title', $xoopsModule->name());
if ($user_id > 0) {
    $blogOwner = new XoopsUser($user_id);
    $page_subtitle = sprintf(_MD_WEBLOG_ENTRIES_FOR, $blogOwner->getVar('uname','E'));
    $page_rss = sprintf(_MD_WEBLOG_RSS_RECENT_FOR, $blogOwner->getVar('uname', 'E'));
} elseif($date > 0) {
    $subtitle = '';
    if(strlen(strval($date)) == 8) {
         preg_match("/(\d{4})(\d{2})(\d{2})/", $date, $matches);
         $subtitle = $matches[1].'/'.$matches[2].'/'.$matches[3];
    } elseif(strlen(strval($date)) == 6) {
         preg_match("/(\d{4})(\d{2})/", $date, $matches);
         $subtitle = $matches[1].'/'.$matches[2];
    } elseif(strlen(strval($date)) == 4) {
         preg_match("/(\d{4})/", $date, $matches);
         $subtitle = $matches[1];
    }
    $page_subtitle = sprintf(_MD_WEBLOG_ENTRIES_FOR_DATE, $subtitle);
} elseif($cat_id>0) {
	$cat =& $weblogcat->getCategory($cat_id);
	$page_subtitle = sprintf(_MD_WEBLOG_ENTRIES_FOR_CATEGORY, $cat->getVar('cat_title'));
} else {
    $page_subtitle = $entryObject->getVar('title');
}

// breadcrumbs info
$xoopsTpl->assign('page_subtitle', $page_subtitle);
$xoopsTpl->assign('mydirname', $mydirname);

$query_string = '';
if($user_id > 0) $query_string .= '?user_id='.intval($user_id);
if($cat_id > 0) $query_string .= ($query_string=='')?'?':'&amp;'.'cat_id='.strval($cat_id);
if($date > 0) $query_string .= ($query_string=='')?'?':'&amp;'.'date='.strval($date);

// category breadcrumbs
// for xugj_assign.php
$breadcrumbs = $weblogcat->getNicePathArrayFromId($cat_id,
                            sprintf('%s/modules/%s/index.php', XOOPS_URL, $mydirname));
array_unshift($breadcrumbs, array('name'=>$xoopsModule->name(), 'url'=>sprintf('%s/modules/%s/index.php', XOOPS_URL, $mydirname))); 
array_push($breadcrumbs, array('name'=>$entryObject->getVar('title'), 'url'=>''));
$xoopsTpl->assign('xoops_breadcrumbs', $breadcrumbs);

// for cruising within the specified category
$cat_ids = array();
if($cat_id > 0) {
    $cat_ids = $weblogcat->getAllChildrenIds($cat_id);
    array_unshift($cat_ids, $cat_id);
}

// navigation for next/previous
$prevnext_id = $weblog->getPrevNext($blog_id , $entryObject->getVar('created')-$useroffset*3600 , $currentuid , $isAdmin, $cat_ids, $user_id, $date, $useroffset) ;
if(isset($prevnext_id['next'])){
	$next_blogentry = sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL, $mydirname, $prevnext_id['next'] );
	// for cruising thru the specified user_id or category or date
    if($user_id > 0) $next_blogentry .= '&amp;user_id='.$user_id;
	if($cat_id > 0) $next_blogentry .= '&amp;cat_id='.$cat_id;
	if($date > 0) $next_blogentry .= '&amp;date='.$date;
    $xoopsTpl->assign('next_blogentry' , $next_blogentry);
}else{
    $xoopsTpl->assign('next_blogentry' , '');
}
if(isset($prevnext_id['prev'])){
	$prev_blogentry = sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL, $mydirname, $prevnext_id['prev']);
	// for cruising thru the specified user_id or category or date
    if($user_id > 0) $prev_blogentry .= '&amp;user_id='.$user_id;
	if($cat_id > 0) $prev_blogentry .= '&amp;cat_id='.$cat_id;
	if($date > 0) $prev_blogentry .= '&amp;date='.$date;
    $xoopsTpl->assign('prev_blogentry' , $prev_blogentry);
}else{
    $xoopsTpl->assign('prev_blogentry' , '');
}
$xoopsTpl->assign('trackback_transmit' , $trackback_transmit ) ;
$xoopsTpl->assign('trackback_received' , $trackback_received ) ;
$xoopsTpl->assign('weblog_trackback_url' , $weblog_trackback_url) ;
$xoopsTpl->assign('weblog_topurl' , sprintf('%s/modules/%s/index.php', XOOPS_URL, $mydirname) ) ;
$xoopsTpl->assign('moduleconfig', @$GLOBALS['xoopsModuleConfig']);

// hodaka assigns a style-sheet to the module header
$weblog_head = sprintf('<link rel="stylesheet" type="text/css" media="all" href="%s/modules/%s/css/style.css" />'."\n" , XOOPS_URL , $mydirname );
$iearound = <<<DOC_END
<!--[if lt IE 7]>
%s
<![endif]-->\n
DOC_END;
$weblog_head .= sprintf($iearound, sprintf('<link rel="stylesheet" type="text/css" media="all" href="%s/modules/%s/css/styleIE.css" />' , XOOPS_URL , $mydirname));
$weblog_head .= sprintf('<link rel="alternate" type="application/rss+xml" title="RSS2.0" href="%s" />'."\n" , $rss_feeder );
$weblog_head .= sprintf('<link rel="alternate" type="application/rdf+xml" title="RDF" href="%s" />'."\n" , $rdf_feeder );
$weblog_head .= sprintf('<link rel="alternate" type="application/atom+xml" title="ATOM" href="%s" />'."\n" , $atom_feeder );
$weblog_head .= sprintf('<script type="text/javascript" src="%s/modules/%s/js/xmlhttp.js"></script>', XOOPS_URL, $mydirname );
$weblog_head .= sprintf('<script type="text/javascript" src="%s/modules/%s/js/tbkey.js"></script>', XOOPS_URL, $mydirname );
$xoopsTpl->assign('xoops_module_header', $xoopsTpl->get_template_vars('xoops_module_header').$weblog_head );

// Include the commenting module
require XOOPS_ROOT_PATH.'/include/comment_view.php';

include(XOOPS_ROOT_PATH.'/footer.php');
?>