<?php
/*
 * $Id: index.php 315 2007-07-09 05:44:24Z hodaka $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

require_once dirname(dirname(__FILE__)).'/include/header.php';
require_once dirname(dirname(__FILE__)).'/class/class.weblog.php';
require_once dirname(dirname(__FILE__)).'/class/class.weblogcategories.php';

// obtain GET/POST parameters
$user_id = !empty($_GET['user_id']) ? intval($_GET['user_id']) : 0;
$start = !empty($_GET['start']) ? intval($_GET['start']) : 0;
$cat_id = !empty($_GET['cat_id']) ? intval($_GET['cat_id']) : 0;
$date = !empty($_GET['date']) ? intval($_GET['date']) : 0;	// YYYY or YYYYMM or YYYYMMDD

// privilege check
require_once dirname(dirname(__FILE__)).'/include/privilege.inc.php';
$isAdmin = ( isset($xoopsUser) && is_object($xoopsUser) ) ? $xoopsUser->isAdmin($xoopsModule->mid()) : false ;
if( ! $isAdmin && ! checkprivilege( "read_index" , $mydirname , $cat_id ) ){
    redirect_header(sprintf('%s/index.php', XOOPS_URL ), 2, _MD_WEBLOG_CANNOT_READ_SORRY);
    exit();
}

// obtain configuration parameters
$perPage = $xoopsModuleConfig['numperpage'];

// Determine the user we are retrieving the blog entries for
if (is_object($xoopsUser)) {
    $isAdmin = $xoopsUser->isAdmin($xoopsModule->mid());
    $currentuid = $xoopsUser->getVar('uid');
    $useroffset = $xoopsUser->timezone() - $xoopsConfig['server_TZ'] ;   
} else {
    $isAdmin = false;
    $currentuid = 0;
    $useroffset = $xoopsConfig['default_TZ'] - $xoopsConfig['server_TZ'] ; 
}

// specify template
$xoopsOption['template_main'] = $mydirname.'_main_entries.html';

// obtain class instances
$myts =& MyTextSanitizer::getInstance();
$weblog =& Weblog::getInstance();
$weblogcat =& WeblogCategories::getInstance();

// read all the categories
$all_categories =& $weblogcat->getObjects(null, true);

if ($user_id > 0) {
    $blogOwner = new XoopsUser($user_id);
    $page_subtitle = sprintf(_MD_WEBLOG_ENTRIES_FOR, $blogOwner->getVar('uname','E'));
    $page_rss = sprintf(_MD_WEBLOG_RSS_RECENT_FOR, $blogOwner->getVar('uname', 'E'));
} elseif($date > 0) {
    $subtitle = '';
    if(strlen(strval($date)) == 8) {
        preg_match("/(\d{4})(\d{2})(\d{2})/", $date, $matches);
        $subtitle = $matches[1].'/'.$matches[2].'/'.$matches[3];
    } elseif(strlen(strval($date)) == 6) {
        preg_match("/(\d{4})(\d{2})/", $date, $matches);
        $subtitle = $matches[1].'/'.$matches[2];
    } elseif(strlen(strval($date)) == 4) {
        preg_match("/(\d{4})/", $date, $matches);
        $subtitle = $matches[1];
    }
	$page_subtitle = sprintf(_MD_WEBLOG_ENTRIES_FOR_DATE, $subtitle);
} elseif($cat_id>0) {
	$cat =& $weblogcat->getCategory($cat_id);
	$page_subtitle = sprintf(_MD_WEBLOG_ENTRIES_FOR_CATEGORY, $cat->getVar('cat_title'));
} else {
    $page_subtitle = _MD_WEBLOG_MOST_RECENT;
}
$page_rss = _MD_WEBLOG_RSS_RECENT;

if ($xoopsModuleConfig['update_reads_when'] == 2 && $user_id > 0 ||
    $xoopsModuleConfig['update_reads_when'] == 3) {
    $updateReads = true;
} else {
    $updateReads = false;
}

// obtain row count
$cat_ids = getAllChildId($all_categories, $cat_id);
array_unshift($cat_ids, $cat_id);
$count = $weblog->getArchivesCount($currentuid, $user_id, $date, $cat_ids, $useroffset);
// obtain entries
$weblog_result = $weblog->getArchives($currentuid, $user_id, $date, $cat_ids, $start, $perPage, $useroffset);

// Include the page header
include_once(XOOPS_ROOT_PATH.'/header.php');

// Category navigation
if( $xoopsModuleConfig['show_category_list'] ){
	$category_navi = array() ;
    $permed = getPermedIds($all_categories);
    $children = getChildTreeArray($all_categories, $permed);
	$categories = array();
	foreach ( $children as $child ) {
		if(strlen($child['prefix'])==1 && count($categories)){
			$category_navi[] = $categories;
			$categories = array();
		}
		$category['level'] = strval(strlen($child['prefix']));
		$category['prefix'] = $child['prefix'];
		$category['cat_id'] = $child['cat_id'];
		$category['cat_title'] = $myts->htmlSpecialChars($child['cat_title']);
		$cid_array = $weblogcat->getAllChildrenIds($child['cat_id']);
		array_push($cid_array, $child['cat_id']);
		$category['count'] = $weblog->getCountByCategories($currentuid, $cid_array, $user_id, $date);
		$categories[] = $category;
	}
	$category_navi[] = $categories;
	$xoopsTpl->assign('category_col', $xoopsModuleConfig['category_col']);
	$xoopsTpl->assign('category_navi', $category_navi);
}
$xoopsTpl->assign('show_category_list', $xoopsModuleConfig['show_category_list']);

// add page navigator if # of entries bigger than # per page
$totalPages = ceil($count / $perPage);
if ( $count > $perPage ) {
    $uri='';
    if ($user_id>0) {
        $uri .= 'user_id='.$user_id;
    }
    if ($date>0) {
        if (strlen($uri)>0) {
            $uri .= '&amp;';
        }
        $uri .= 'date='.$date;
    }
    if ($cat_id>0) {
        if (strlen($uri)>0) {
            $uri .= '&amp;';
        }
        $uri .= 'cat_id='.$cat_id;
    }
    include_once XOOPS_ROOT_PATH.'/class/pagenav.php';
    $nav = new XoopsPageNav($count, $perPage, $start, "start", $uri);
    $xoopsTpl->assign('pagination', $nav->renderNav());
} else {
    $xoopsTpl->assign('pagination', '');
}

foreach ($weblog_result as $entryObject) {
    $entry = array();
    if ($updateReads==true) {
        $curtime = time();
        $blog_id = $entryObject->getVar('blog_id');
        // wellwine for cookie begins
        // Read in cookie
        $weblog_read = !empty($_COOKIE[WEBLOG_COOKIE_READ]) ? unserialize($_COOKIE[WEBLOG_COOKIE_READ]) : array();
        // if cookie is not set for this blog, update view count and set cookie
        if ( empty($weblog_read[$blog_id]) || $weblog_read[$blog_id] + $xoopsModuleConfig['expiration'] < $curtime ) {
            $reads = $weblog->incrementReads($blog_id);
            $entryObject->setVar('reads', $reads);
        }
        // Update cookie
        // FIXME: doesn't check if 4kB limit of cookie is exceeded!
        $weblog_read[$blog_id] = $curtime;
        setcookie(WEBLOG_COOKIE_READ, serialize($weblog_read), $curtime+$xoopsModuleConfig['expiration'], $weblogCookie['path'], $weblogCookie['domain'], $weblogCookie['secure']);
        // wellwine for cookie ends
    }

    // create rdf 
	require_once dirname(dirname(__FILE__)).'/include/PEAR/Net/TrackBack.php';
    $weblog_trackback_url = XOOPS_URL.'/modules/'.$mydirname.'/weblog-tb.php/'. $entryObject->getVar('blog_id');
    $net_trackback =& new Net_TrackBack();
    if( $xoopsConfig['default_TZ'] < 0 ){
        $TZ = "-" . sprintf('%02d', abs($xoopsConfig['default_TZ']) ) . ':00';
    }else{
        $TZ = "+" . sprintf('%02d', $xoopsConfig['default_TZ'] ) . ':00';
    }
    $rdf_source_data = array(
    'about'=> sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL , $mydirname , $entryObject->getVar('blog_id') ) ,
    'ping'=> $weblog_trackback_url ,
    'title'=> addslashes($entryObject->getVar('title')) ,
    'identifier'=> sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL , $mydirname , $entryObject->getVar('blog_id') ),
	// strip entry division separator
    'description'=> strip_tags(addslashes(xoops_substr( str_replace( _MD_WEBLOG_ENTRY_SEPARATOR_DELIMETER , "" , $entryObject->getvar('contents','s')) , 0 , WEBLOG_RDF_DESCRIPTION_NUM ) ) ),
    'creator'=> $entryObject->getVar('uname'),
    'date'=> date("Y-m-d\TH:i:s" , $entryObject->getVar('created')) . $TZ
    ) ;
    $rdf_desc = "<!-- \n" . $net_trackback->toEmbededRDF($rdf_source_data) . "-->\n";

    // Retrieve his/her avatar
    $entry['use_avatar'] = 0;
    $entry['avatar_img'] = '';
    $entry['avatar_width'] = 0;
    $entry['avatar_height'] = 0;
    if ($xoopsModuleConfig['showavatar']) {
        $avatar = $entryObject->getVar('user_avatar', 'E');
        if (!empty($avatar) && $avatar != 'blank.gif') {
            $entry['use_avatar'] = 1;
            $entry['avatar_img'] = sprintf('%s/%s', XOOPS_UPLOAD_URL, $avatar);
            $dimension = getimagesize(sprintf('%s/%s', XOOPS_UPLOAD_PATH, $avatar));
            $entry['avatar_width'] = is_array($dimension)? $dimension[0] : '' ;
            $entry['avatar_height'] = is_array($dimension)? $dimension[1] : '' ;
        }
    }

	$entry['created'] = formatTimestamp($entryObject->getVar('created'),
                         	$xoopsModuleConfig['dateformat'].' '.$xoopsModuleConfig['timeformat'],
                            $xoopsConfig['default_TZ']);
    $entry['uid'] = $entryObject->getVar('user_id');
    $entry['uname'] = $entryObject->getVar('uname');
    $entry['title'] = $entryObject->getVar('title');
	$addstring = '';
	$addstring .= ($cat_id > 0)? '&amp;cat_id='.$cat_id : '';
	$addstring .= ($date > 0)? '&amp;date='.$date : '';
	$entry['contents'] = $entryObject->getVar('contents','s' , $entryObject->getVar('blog_id').$addstring , 'index');
    $entry['category'] = getCategoryStructureFromId($all_categories, $entryObject->getVar('cat_id'));
    $entry['profileUri'] = sprintf('%s/userinfo.php?uid=%d', XOOPS_URL, $entryObject->getVar('user_id'));
    $entry['blog_id'] = $entryObject->getVar('blog_id');
    $entry['comments'] = $entryObject->getVar('comments');
    $entry['comlink'] = sprintf('%s/modules/%s/details.php?blog_id=%d#comment',
                            XOOPS_URL, $mydirname, $entryObject->getVar('blog_id'));

    $entry['is_private'] = ($entryObject->getVar('private')=='Y')?1:0;
    $entry['provide_edit_link'] = ($isAdmin || ($currentuid==$entryObject->getVar('user_id') && checkprivilege("edit",$mydirname)))?1:0;
    $entry['reads'] = $entryObject->getVar('reads');
    $entry['trackbacks'] = $entryObject->getVar('trackbacks');
    $entry['tracklink'] = sprintf('%s/modules/%s/details.php?blog_id=%d',
                              XOOPS_URL, $mydirname, $entryObject->getVar('blog_id'));
    $entry['rdf_desc'] = $rdf_desc ;
    $xoopsTpl->append('entries', $entry);
}

// wellwine
$rss = sprintf('%s/modules/%s/backend_weblog.php', XOOPS_URL, $mydirname);
$rdf = sprintf('%s/modules/%s/weblog-rdf.php', XOOPS_URL, $mydirname);
$atom = sprintf('%s/modules/%s/weblog-atom.php', XOOPS_URL, $mydirname);
if ($user_id>0) {
    $rss .= sprintf('?user_id=%d', $user_id);
    $rdf .= sprintf('?user_id=%d', $user_id);
}
$xoopsTpl->assign('lang_rss', $page_rss);
$xoopsTpl->assign('rss_feeder', $rss);
$xoopsTpl->assign('rdf_feeder', $rdf);
$xoopsTpl->assign('atom_feeder', $atom);
$xoopsTpl->assign('rss_show', $xoopsModuleConfig['rssshow']);

$xoopsTpl->assign('page_title', $xoopsModule->name());
$xoopsTpl->assign('cat_id', $cat_id);
$xoopsTpl->assign('user_id', $date);
$xoopsTpl->assign('date', $date);
$append = '';
if($user_id > 0) $append .= '&amp;user_id='.intval($user_id);
if($date > 0) $append .= '&amp;date='.strval($date);
$xoopsTpl->assign('append', $append);
$query_append = ($cat_id> 0)? '&amp;cat_id='.intval($cat_id) : '' . $append;
$xoopsTpl->assign('query_append', $query_append);
$xoopsTpl->assign('page_subtitle', $page_subtitle);
$xoopsTpl->assign('mydirname', $mydirname);
$xoopsTpl->assign('weblog_topurl', sprintf('%s/modules/%s/index.php', XOOPS_URL, $mydirname));

// category breadcrumbs
$breadcrumbs = getNicePathArrayFromId($all_categories, $cat_id, sprintf('%s/modules/%s/index.php', XOOPS_URL, $mydirname));
$xoopsTpl->assign('category_breadcrumbs', $breadcrumbs);
// breadcrumbs info
array_unshift($breadcrumbs, array('name'=>$xoopsModule->name(), 'url'=>sprintf('%s/modules/%s/', XOOPS_URL, $mydirname))); 
if($cat_id <= 0)
    array_push($breadcrumbs, array('name'=>$page_subtitle, 'url'=>''));
$xoopsTpl->assign('xoops_breadcrumbs', $breadcrumbs);

// meta header
$weblog_head = sprintf('<link rel="stylesheet" type="text/css" media="all" href="%s/modules/%s/css/style.css" />'."\n" , XOOPS_URL , $mydirname );
$iearound = <<<DOC_END
<!--[if lt IE 7]>
%s
<![endif]-->\n
DOC_END;
$weblog_head .= sprintf($iearound, sprintf('<link rel="stylesheet" type="text/css" media="all" href="%s/modules/%s/css/styleIE.css" />' , XOOPS_URL , $mydirname));
$weblog_head .= sprintf('<link rel="alternate" type="application/rss+xml" title="RSS2.0" href="%s" />'."\n" , $rss );
$weblog_head .= sprintf('<link rel="alternate" type="application/rdf+xml" title="RDF" href="%s" />'."\n" , $rdf );
$weblog_head .= sprintf('<link rel="alternate" type="application/atom+xml" title="ATOM" href="%s" />'."\n" , $atom );
$xoopsTpl->assign('xoops_module_header', $xoopsTpl->get_template_vars('xoops_module_header').$weblog_head );

// Include the page footer
include_once(XOOPS_ROOT_PATH.'/footer.php');
?>
